==> apache-seata-2.4.0-incubating-src.tar.gz: apache-seata-2.4.0-incubating-src/config/seata-config-custom/src/test/java/org/apache/seata/config/CustomConfigurationTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.seata.config;

import java.io.InputStream;
import java.util.Properties;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;


public class CustomConfigurationTest {
    @Test
    public void testCustomConfigLoad() throws Exception {
        ConfigurationCache.clear();
        Configuration configuration = ConfigurationFactory.getInstance();
        Assertions.assertNotNull(configuration);
        Properties properties;
        try (InputStream input = CustomConfigurationForTest.class.getClassLoader().getResourceAsStream("custom_for_test.properties")) {
            properties = new Properties();
            properties.load(input);
        }
        Assertions.assertNotNull(properties);
        for (String name : properties.stringPropertyNames()) {
            String value = properties.getProperty(name);
            Assertions.assertNotNull(value);
            Assertions.assertEquals(value, configuration.getConfig(name));
        }
    }
}

==> apache-seata-2.6.0-incubating-src.tar.gz: apache-seata-2.6.0-incubating-src/config/seata-config-custom/src/test/java/org/apache/seata/config/CustomConfigurationTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.seata.config;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

import java.io.InputStream;
import java.util.Properties;

public class CustomConfigurationTest {
    @Test
    public void testCustomConfigLoad() throws Exception {
        ConfigurationCache.clear();
        Configuration configuration = ConfigurationFactory.getInstance();
        Assertions.assertNotNull(configuration);
        Properties properties;
        try (InputStream input =
                CustomConfigurationForTest.class.getClassLoader().getResourceAsStream("custom_for_test.properties")) {
            properties = new Properties();
            properties.load(input);
        }
        Assertions.assertNotNull(properties);
        for (String name : properties.stringPropertyNames()) {
            String value = properties.getProperty(name);
            Assertions.assertNotNull(value);
            Assertions.assertEquals(value, configuration.getConfig(name));
        }
    }
}
